@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "cswordbackend.h"
@@ -13,6 +22,7 @@
 #include "bt_thmlhtml.h"
 #include "bt_osishtml.h"
 #include "bt_gbfhtml.h"
+#include "bt_plainhtml.h"
 #include "osismorphsegmentation.h"
 
 #include "frontend/cbtconfig.h"
@@ -33,7 +43,6 @@
 #include <swdisp.h>
 #include <swfiltermgr.h>
 #include <encfiltmgr.h>
-#include <plainhtml.h>
 #include <rtfhtml.h>
 #include <filemgr.h>
 #include <utilstr.h>
@@ -136,8 +145,12 @@ const CSwordBackend::LoadError CSwordBackend::initModules() {
 			);
 		}
 
-		if (newModule) { //append the new modules to our list
-			m_moduleList.append( newModule );
+		if (newModule) { 
+			//append the new modules to our list, but only if it's supported
+			//the constructor of CSwordModuleInfo prints a waring on stdout
+			if (!newModule->hasVersion() || (newModule->minimumSwordVersion() <= sword::SWVersion::currentVersion)) {
+				m_moduleList.append( newModule );	
+			}
 		}
 	}
 
@@ -178,30 +191,24 @@ void CSwordBackend::AddRenderFilters(sword::SWModule *module, sword::ConfigEntMa
 		if (!m_filters.gbf) {
 			m_filters.gbf = new BT_GBFHTML();
 		}
-
 		module->AddRenderFilter(m_filters.gbf);
 		noDriver = false;
 	}
-
-	if (sourceformat == "PLAIN") {
+	else if (sourceformat == "PLAIN") {
 		if (!m_filters.plain) {
-			m_filters.plain = new sword::PLAINHTML();
+			m_filters.plain = new BT_PLAINHTML();
 		}
-
 		module->AddRenderFilter(m_filters.plain);
 		noDriver = false;
 	}
-
-	if (sourceformat == "ThML") {
+	else if (sourceformat == "ThML") {
 		if (!m_filters.thml) {
 			m_filters.thml = new BT_ThMLHTML();
 		}
-
 		module->AddRenderFilter(m_filters.thml);
 		noDriver = false;
 	}
-
-	if (sourceformat == "OSIS") {
+	else if (sourceformat == "OSIS") {
 		if (!m_filters.osis) {
 			m_filters.osis = new BT_OSISHTML();
 		}
@@ -211,12 +218,10 @@ void CSwordBackend::AddRenderFilters(sword::SWModule *module, sword::ConfigEntMa
 	}
 
 	if (noDriver) { //no driver found
-
 		if ( (moduleDriver == "RawCom") || (moduleDriver == "RawLD") ) {
 			if (!m_filters.plain) {
-				m_filters.plain = new sword::PLAINHTML();
+				m_filters.plain = new BT_PLAINHTML();
 			}
-
 			module->AddRenderFilter(m_filters.plain);
 			noDriver = false;
 		}
@@ -614,9 +619,9 @@ const QString CSwordBackend::configOptionName( const CSwordModuleInfo::FilterTyp
 
 const QString CSwordBackend::booknameLanguage( const QString& language ) {
 	if (!language.isEmpty()) {
-		qDebug("setting language %s", language.latin1());
+//		qDebug("setting language %s", language.latin1());
 		sword::LocaleMgr::getSystemLocaleMgr()->setDefaultLocaleName( language.latin1() );
-		qDebug("got language %s", sword::LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName() );
+//		qDebug("got language %s", sword::LocaleMgr::getSystemLocaleMgr()->getDefaultLocaleName() );
 
 		//refresh the locale of all Bible and commentary modules!
 		const ListCSwordModuleInfo::iterator end_it = m_moduleList.end();
@@ -705,7 +710,7 @@ const QStringList CSwordBackend::swordDirList() {
 void CSwordBackend::filterInit() {
 	//  qWarning("## INIT");
 
-	SWFilter* tmpFilter = new OSISMorphSegmentation();
-	optionFilters.insert(FilterMap::value_type("OSISMorphSegmentation", tmpFilter));
+	SWOptionFilter* tmpFilter = new OSISMorphSegmentation();
+	optionFilters.insert(OptionFilterMap::value_type("OSISMorphSegmentation", tmpFilter));
 	cleanupFilters.push_back(tmpFilter);
 }
