@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: osismorphsegmentation.h,v 1.3 2005/09/02 22:15:30 joachim Exp $
+ * $Id: osismorphsegmentation.h,v 1.4 2006/08/08 19:32:48 joachim Exp $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  * CrossWire Bible Society
@@ -27,17 +27,21 @@ using namespace sword;
 
 namespace Filters {
 
-	/** This Filter shows/hides headings in a OSIS text
-	 */
-
+/** This Filter shows/hides headings in a OSIS text.
+ * @author Martin Gruner
+ */
 class OSISMorphSegmentation : public SWOptionFilter {
+	static const char oName[];
+	static const char oTip[];
+	static const SWBuf choices[3];
+	static const StringList oValues;
 
 public:
-		OSISMorphSegmentation();
-		virtual ~OSISMorphSegmentation();
+	OSISMorphSegmentation();
+	virtual ~OSISMorphSegmentation();
 
-		virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
-	};
+	virtual char processText(SWBuf &text, const SWKey *key = 0, const SWModule *module = 0);
+};
 
 }
 
