@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "bibletime.h"
@@ -10,6 +19,7 @@
 
 //Sword includes
 #include <versekey.h>
+#include <listkey.h>
 
 //helper function
 void BibleTime::syncAllModulesByType(const CSwordModuleInfo::ModuleType type, const QString& key) {
@@ -77,9 +87,12 @@ QStringList BibleTime::searchInModule(const QString& moduleName, const QString&
 	QStringList ret;
 	CSwordModuleInfo* mod = CPointers::backend()->findModuleByName(moduleName);
 
+	//TODO: Check this
 	Q_ASSERT(mod);
 	if (mod) {
-		mod->search(searchText, CSwordModuleSearch::multipleWords, sword::ListKey());
+		//mod->search(searchText, CSwordModuleSearch::multipleWords, sword::ListKey());
+		sword::ListKey scope;
+		mod->searchIndexed( searchText, scope );
 
 		sword::ListKey result = mod->searchResult();
 		const QString lead = QString("[%1] ").arg(moduleName);
@@ -199,3 +212,9 @@ QStringList BibleTime::getModulesOfType(const QString& type) {
 
 	return ret;
 }
+
+void BibleTime::reloadModules() {
+	//m_backend->reloadModules();
+	slotSwordSetupChanged();
+}
+
