@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "bibletime.h"
@@ -13,6 +22,7 @@
 #include "frontend/kstartuplogo.h"
 #include "frontend/cswordsetupdialog.h"
 #include "frontend/cprinter.h"
+#include "frontend/cmanageindiceswidget.h"
 
 #include "backend/clanguagemgr.h"
 
@@ -58,17 +68,22 @@
 #include <swlog.h>
 
 using namespace InfoDisplay;
+using namespace Profile;
 
 /**Initializes the view of this widget*/
 void BibleTime::initView() {
 	KStartupLogo::setStatusMessage(i18n("Creating BibleTime's GUI") + QString("..."));
 
 	m_mainSplitter = new QSplitter(this, "mainsplitter");
+	m_mainSplitter->setChildrenCollapsible(false);
 	setCentralWidget(m_mainSplitter);
 
 	m_leftPaneSplitter = new QSplitter(Qt::Vertical, m_mainSplitter);
-
+	m_leftPaneSplitter->setChildrenCollapsible(false);
+	
 	QVBox* vBox = new QVBox(m_leftPaneSplitter);
+	vBox->setMinimumSize(100, 100);
+	
 	QLabel* bookshelfLabel = new QLabel( i18n("Bookshelf"), vBox );
 	bookshelfLabel->setMargin(5);
 
@@ -78,6 +93,7 @@ void BibleTime::initView() {
 	CPointers::setInfoDisplay(m_infoDisplay);
 
 	m_mdi = new CMDIArea(m_mainSplitter, "mdiarea" );
+	m_mdi->setMinimumSize(100, 100);
 	m_mdi->setFocusPolicy(ClickFocus);
 
 	m_helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), true, actionCollection());
@@ -189,12 +205,11 @@ void BibleTime::initActions() {
 	action->plugAccel( accel() );
 	#endif
 
-	m_windowArrangementMode_action = new KActionMenu(
-										 i18n("&Arrangement mode"),
-										 CResMgr::mainMenu::window::arrangementMode::icon,
-										 actionCollection(),
-										 CResMgr::mainMenu::window::arrangementMode::actionName
-									 );
+	m_windowArrangementMode_action = new KActionMenu(i18n("&Arrangement mode"),
+							 CResMgr::mainMenu::window::arrangementMode::icon,
+							 actionCollection(),
+							 CResMgr::mainMenu::window::arrangementMode::actionName);
+	m_windowArrangementMode_action->setDelayed( false );
 
 	m_windowManualMode_action = new KToggleAction(i18n("&Manual mode"),
 								CResMgr::mainMenu::window::arrangementMode::manual::icon,
@@ -322,6 +337,7 @@ void BibleTime::initActions() {
 								 CResMgr::mainMenu::window::saveProfile::actionName
 												);
 	m_windowSaveProfile_action->setToolTip( CResMgr::mainMenu::window::saveProfile::tooltip );
+	m_windowSaveProfile_action->setDelayed( false );
 	#if KDE_VERSION_MINOR < 1
 
 	m_windowSaveProfile_action->plugAccel( accel() );
@@ -346,9 +362,8 @@ void BibleTime::initActions() {
 								 actionCollection(),
 								 CResMgr::mainMenu::window::loadProfile::actionName
 												);
-	m_windowLoadProfile_action->setToolTip(
-		CResMgr::mainMenu::window::loadProfile::tooltip
-	);
+	m_windowLoadProfile_action->setToolTip(	CResMgr::mainMenu::window::loadProfile::tooltip	);
+	m_windowLoadProfile_action->setDelayed( false );
 	#if KDE_VERSION_MINOR < 1
 
 	m_windowLoadProfile_action->plugAccel( accel() );
@@ -359,9 +374,8 @@ void BibleTime::initActions() {
 								   actionCollection(),
 								   CResMgr::mainMenu::window::deleteProfile::actionName
 												  );
-	m_windowLoadProfile_action->setToolTip(
-		CResMgr::mainMenu::window::deleteProfile::tooltip
-	);
+	m_windowLoadProfile_action->setToolTip( CResMgr::mainMenu::window::deleteProfile::tooltip );
+	m_windowLoadProfile_action->setDelayed( false );
 	#if KDE_VERSION_MINOR < 1
 
 	m_windowDeleteProfile_action->plugAccel( accel() );
@@ -499,6 +513,7 @@ void BibleTime::initConnections() {
 		m_mainIndex, SIGNAL(createWriteDisplayWindow(CSwordModuleInfo*, const QString&, const CDisplayWindow::WriteWindowType&)),
 		this, SLOT(createWriteDisplayWindow(CSwordModuleInfo*,const QString&, const CDisplayWindow::WriteWindowType&))
 	);
+	connect(m_mainIndex, SIGNAL(signalSwordSetupChanged()), this, SLOT(slotSwordSetupChanged()));
 }
 
 /** Initializes the backend */
@@ -526,8 +541,8 @@ void BibleTime::initBackends() {
 			case CSwordBackend::NoSwordConfig: //mods.d or mods.conf missing
 			{
 				KStartupLogo::hideSplash();
-				InstallationManager::CSwordSetupDialog dlg;
-				dlg.showPart( InstallationManager::CSwordSetupDialog::Sword );
+				BookshelfManager::CSwordSetupDialog dlg;
+				dlg.showPart( BookshelfManager::CSwordSetupDialog::Sword );
 				dlg.exec();
 				break;
 			}
@@ -535,8 +550,8 @@ void BibleTime::initBackends() {
 			case CSwordBackend::NoModules: //no modules installed, but config exists
 			{
 				KStartupLogo::hideSplash();
-				InstallationManager::CSwordSetupDialog dlg;
-				dlg.showPart( InstallationManager::CSwordSetupDialog::Install );
+				BookshelfManager::CSwordSetupDialog dlg;
+				dlg.showPart( BookshelfManager::CSwordSetupDialog::Install );
 				dlg.exec();
 				break;
 			}
@@ -544,19 +559,20 @@ void BibleTime::initBackends() {
 			default: //unknown error
 			{
 				KStartupLogo::hideSplash();
-				InstallationManager::CSwordSetupDialog dlg;
-				dlg.showPart( InstallationManager::CSwordSetupDialog::Sword );
+				BookshelfManager::CSwordSetupDialog dlg;
+				dlg.showPart( BookshelfManager::CSwordSetupDialog::Sword );
 				dlg.exec();
 				break;
 			}
 		}
 	}
-}
 
-/** Initializes the CPrinter object. */
-void BibleTime::initPrinter() {
-	KStartupLogo::setStatusMessage(i18n("Initializing print system") + QString("..."));
-	CPointers::setPrinter( (m_printer = new Printing::CPrinter(this)) );
+	KStartupLogo::setStatusMessage(i18n("Checking indices") + QString("..."));
+	//This function will 
+	// - delete all orphaned indexes (no module present) if autoDeleteOrphanedIndices is true
+	// - delete all indices of modules where hasIndex() returns false
+	BookshelfManager::CManageIndicesWidget::deleteOrphanedIndices();
+	
 }
 
 /** Apply the settings given by the profile p*/
@@ -572,6 +588,12 @@ void BibleTime::applyProfileSettings( CProfile* p ) {
 		qDebug("main window: %i, %i @ %i x %i", geometry.topLeft().x(), geometry.topLeft().y(), geometry.width(), geometry.height());
 		KMainWindow::resize( geometry.size() ); //Don't use KMainWindowInterface::resize
 		KMainWindow::move( geometry.topLeft() );//Don't use KMainWindowInterface::move
+		if (p->maximized()) {
+			KMainWindow::showMaximized();
+		}
+		else{
+			KMainWindow::showNormal();
+		}
 	}
 
 	m_windowFullscreen_action->setChecked( p->fullscreen() );  //set the fullscreen button state
@@ -586,6 +608,7 @@ void BibleTime::storeProfileSettings( CProfile* p ) {
 	}
 
 	p->setFullscreen( m_windowFullscreen_action->isChecked() );
+	p->setMaximized( this->KMainWindow::isMaximized() );
 
 	QRect geometry;
 	geometry.setTopLeft(pos());
