@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CBTCONFIG_H
 #define CBTCONFIG_H
@@ -59,6 +68,7 @@ public:
 
 		tips,
 		logo,
+		autoDeleteOrphanedIndices,
 		crashedLastTime,
 		crashedTwoTimes
 	};
