@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "creaddisplay.h"
@@ -49,7 +58,7 @@ const bool CReadDisplay::hasActiveAnchor() {
 }
 
 
-void CReadDisplay::print(const CDisplay::TextPart type) {
+void CReadDisplay::print(const CDisplay::TextPart type, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions) {
 	CDisplayWindow* window = parentWindow();
 	CSwordKey* const key = window->key();
 	CSwordModuleInfo* module = key->module();
@@ -72,10 +81,10 @@ void CReadDisplay::print(const CDisplay::TextPart type) {
 					stopKey.Verse( bible->verseCount( bible->bookNumber(startKey.book()), startKey.Chapter() ) );
 				}
 
-				mgr.printKey(module, startKey.key(), stopKey.key());
+				mgr.printKey(module, startKey.key(), stopKey.key(), displayOptions, filterOptions);
 			}
 			else if (module->type() == CSwordModuleInfo::Lexicon || module->type() == CSwordModuleInfo::Commentary ) {
-				mgr.printKey(module, key->key(), key->key());
+				mgr.printKey(module, key->key(), key->key(), displayOptions, filterOptions);
 			}
 			else if (module->type() == CSwordModuleInfo::GenericBook) {
 				CSwordTreeKey* tree = dynamic_cast<CSwordTreeKey*>(key);
@@ -89,13 +98,13 @@ void CReadDisplay::print(const CDisplay::TextPart type) {
 				//          while ( stopKey.nextSibling() ) { //go to last displayed sibling!
 				//          }
 				//        }
-				mgr.printKey(module, startKey.key(), stopKey.key());
+				mgr.printKey(module, startKey.key(), stopKey.key(), displayOptions, filterOptions);
 			}
 		};
 
 		case AnchorWithText: {
 			if (hasActiveAnchor()) {
-				mgr.printByHyperlink( activeAnchor() );
+				mgr.printByHyperlink( activeAnchor(), displayOptions, filterOptions );
 			};
 		};
 
