@@ -1,9 +1,19 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CREADDISPLAY_H
 #define CREADDISPLAY_H
 
 #include "cdisplay.h"
+#include "backend/cswordbackend.h"
 
 class QPopupMenu;
 class QWidget;
@@ -26,7 +36,7 @@ public:
 	* Moves the widget to the given anchor.
 	*/
 	virtual void moveToAnchor( const QString& ) = 0;
-	virtual void print(const CDisplay::TextPart);
+	virtual void print(const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions);
 
 	void setMouseTracking(const bool trackingEnabled) {
 		m_useMouseTracking = trackingEnabled;
