@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 //BibleTime includes
 #include "cindexitem.h"
@@ -192,7 +201,7 @@ void CModuleItem::dropped( QDropEvent* e, QListViewItem* /*after*/) {
 				ListCSwordModuleInfo modules;
 				modules.append(module());
 
-				CSearchDialog::openDialog(modules, item.text());
+				Search::CSearchDialog::openDialog(modules, item.text());
 			}
 		}
 		else if (CDragDropMgr::dndType(e) == CDragDropMgr::Item::Bookmark) { //open the module
