@@ -9,8 +9,8 @@
 
 
 
-/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.136 2006/08/20 14:01:12 joachim Exp $ */
-/* $Revision: 1.136 $ */
+/* $Header: /cvsroot/bibletime/bibletime/bibletime/main.cpp,v 1.138 2006/11/24 20:24:18 joachim Exp $ */
+/* $Revision: 1.138 $ */
 
 //standard includes
 #include <stdlib.h>
@@ -155,6 +155,8 @@ int main(int argc, char* argv[]) {
 	/***********************************************
 	*        Credits (sorted by last name)         *
 	************************************************/
+	// Update to the Romanian GUI translation
+	aboutData.addCredit("Horatiu Alexe", I18N_NOOP("Romanian translation"), "");
 	//highcolor icons, startlogo for BT <= 1.4
 	aboutData.addCredit("David Blue", I18N_NOOP("High contrast template"), "davidslists@gmx.net");
 	//helped out with the installation manager
@@ -175,8 +177,12 @@ int main(int argc, char* argv[]) {
 	aboutData.addCredit("SIL International", I18N_NOOP("Language codes and names"), "", "http://www.ethnologue.com/iso639");
 	//Indexed search, gui improvements
 	aboutData.addCredit("Lee Carpenter",  I18N_NOOP("GUI, instant search"),"Lee Carpenter <elc@carpie.net>", "http://www.carpie.net");
+	//Update the the Finnish GUI translation
+	aboutData.addCredit("Ilpo Kantonen",  I18N_NOOP("Finnish translation"),"", "");
 	//Smaller frontend enhancements
 	aboutData.addCredit("Chris Kujawa",  I18N_NOOP("Frontend"),"christopher.kujawa@verizon.net", "");
+	//Update to the Czech GUI translation
+	aboutData.addCredit("Pavel Lauko",  I18N_NOOP("Czech translation"),"", "");
 	//Smaller searchdialog enhancements
 	aboutData.addCredit("Mark Lybarger",  I18N_NOOP("Searchdialog"), "mlybarge@insight.rr.com","");
 	//Smaller frontend enhancements
@@ -193,13 +199,17 @@ int main(int argc, char* argv[]) {
 	aboutData.addCredit("Wolfgang Stradner", I18N_NOOP("Very helpful and detailed testing"), "wolfgang_stradner@wycliffe.org", "");
 	//The first lead developer
 	aboutData.addCredit("Torsten Uhlmann",   I18N_NOOP("The first lead developer"), "", "");
+ 	//Update of the dutch website translation(cbiblereadwindow_0)
+	aboutData.addCredit("Johan van der Lingen",   I18N_NOOP("Dutch website translation updates"), "", "");
 	//scoped_ptr and related classes
 	aboutData.addCredit("David White",   I18N_NOOP("Helpful source code additions"), "", "http://www.wesnoth.org/");
 	//Translated the GUI into Russian
 	aboutData.addCredit("Dmitry Yurevich",   I18N_NOOP("Translated the GUI into Russian"), "", "");
 	//The new keychooser for Bible modules
 	aboutData.addCredit("Mark Zealey",   I18N_NOOP("New Bible key choosers"), "mspam@zealey.org", "");
-
+	//Update to the Spanish GUI translation
+ 	aboutData.addCredit("Esteban Zeller",   I18N_NOOP("Spanish translation"), "", "");
+				
 	//special message so the translator get his credits in the about box, don't remove this!
 	QString dummy = I18N_NOOP("_: NAME OF TRANSLATORS\nYour names"); //translator's name
 	dummy = I18N_NOOP("_: EMAIL OF TRANSLATORS\nYour emails"); //translators eMail
