@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #include "cpointers.h"
 
@@ -12,12 +21,6 @@
 
 CPointers::PointerCache m_pointerCache;
 
-void CPointers::setPrinter(Printing::CPrinter* const printer) {
-	Q_ASSERT( m_pointerCache.printer == 0);
-	CPointers::deletePrinter();
-	m_pointerCache.printer = printer;
-}
-
 void CPointers::setBackend(CSwordBackend* const backend) {
 	Q_ASSERT( m_pointerCache.backend == 0);
 	CPointers::deleteBackend();
@@ -29,11 +32,6 @@ void CPointers::setInfoDisplay(InfoDisplay::CInfoDisplay* const infoDisplay) {
 	m_pointerCache.infoDisplay = infoDisplay;
 }
 
-void CPointers::deletePrinter() {
-	delete m_pointerCache.printer;
-	m_pointerCache.printer = 0;
-}
-
 void CPointers::deleteBackend() {
 	delete m_pointerCache.backend;
 	m_pointerCache.backend = 0;
