@@ -1,4 +1,13 @@
-/********* Read the file LICENSE for license details. *********/
+/*********
+*
+* This file is part of BibleTime's source code, http://www.bibletime.info/.
+*
+* Copyright 1999-2006 by the BibleTime developers.
+* The BibleTime source code is licensed under the GNU General Public License version 2.0.
+*
+**********/
+
+
 
 #ifndef CPOINTERS_H
 #define CPOINTERS_H
@@ -12,9 +21,6 @@ class CSwordBackend;
 class CLanguageMgr;
 class CDisplayTemplateMgr;
 
-namespace Printing {
-	class CPrinter;
-}
 namespace InfoDisplay {
 	class CInfoDisplay;
 }
@@ -35,10 +41,6 @@ protected:
 	* @param backend Pointer to the new application-wide Sword backend
 	*/
 	static void setBackend(CSwordBackend* const backend);
-	/** Set the printer instance.
-	* @param printer Pointer to the ne CPrinter instance.
-	*/
-	static void setPrinter(Printing::CPrinter* const printer);
 	/** Set the info display.
 	* @param iDisplay The pointer to the new info display.
 	*/
@@ -62,11 +64,6 @@ protected:
 	static void deleteDisplayTemplateMgr();
 
 public: // Public methods
-	/**
-	* Returns a pointer to the printer object.
-	* @return The printer oobject.
-	*/
-	inline static Printing::CPrinter* const printer();
 	/** Returns a pointer to the backend
 	* @return The backend pointer.
 	*/
@@ -87,14 +84,12 @@ public: // Public methods
 	struct PointerCache {
 		PointerCache() {
 			backend = 0;
-			printer = 0;
 			langMgr = 0;
 			infoDisplay = 0;
 			displayTemplateMgr = 0;
 		};
 
 		CSwordBackend* backend;
-		Printing::CPrinter*      printer;
 		CLanguageMgr*  langMgr;
 		InfoDisplay::CInfoDisplay*  infoDisplay;
 		CDisplayTemplateMgr* displayTemplateMgr;
@@ -116,11 +111,6 @@ inline CLanguageMgr* const CPointers::languageMgr() {
 	return m_pointerCache.langMgr;
 }
 
-/** Returns a pointer to the printer object. */
-inline Printing::CPrinter* const CPointers::printer() {
-	return m_pointerCache.printer;
-}
-
 /** Returns a pointer to the printer object. */
 inline InfoDisplay::CInfoDisplay* const CPointers::infoDisplay() {
 	return m_pointerCache.infoDisplay;
